pub struct CreateNoteRequest {
pub title: String,
pub content: String,
pub tags: Vec<String>,
}Expand description
Request body for creating a note.
Fields
title: Stringcontent: StringTrait Implementations
Sourceimpl Clone for CreateNoteRequest
impl Clone for CreateNoteRequest
Sourcefn clone(&self) -> CreateNoteRequest
fn clone(&self) -> CreateNoteRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CreateNoteRequest
impl ComposeSchema for CreateNoteRequest
Sourceimpl Debug for CreateNoteRequest
impl Debug for CreateNoteRequest
Sourceimpl<'de> Deserialize<'de> for CreateNoteRequest
impl<'de> Deserialize<'de> for CreateNoteRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateNoteRequest
impl JsonSchema for CreateNoteRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CreateNoteRequest
impl Serialize for CreateNoteRequest