pub struct UpdateNoteRequest {
pub title: Option<String>,
pub content: Option<String>,
pub tags: Option<Vec<String>>,
}Expand description
Request body for updating a note.
Fields
title: Option<String>content: Option<String>Trait Implementations
Sourceimpl Clone for UpdateNoteRequest
impl Clone for UpdateNoteRequest
Sourcefn clone(&self) -> UpdateNoteRequest
fn clone(&self) -> UpdateNoteRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpdateNoteRequest
impl ComposeSchema for UpdateNoteRequest
Sourceimpl Debug for UpdateNoteRequest
impl Debug for UpdateNoteRequest
Sourceimpl Default for UpdateNoteRequest
impl Default for UpdateNoteRequest
Sourcefn default() -> UpdateNoteRequest
fn default() -> UpdateNoteRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateNoteRequest
impl<'de> Deserialize<'de> for UpdateNoteRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdateNoteRequest
impl JsonSchema for UpdateNoteRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for UpdateNoteRequest
impl Serialize for UpdateNoteRequest