pub struct UsageBucket {
pub ts: Option<String>,
pub messages: i64,
pub input_tokens: i64,
pub output_tokens: i64,
pub cached_tokens: i64,
pub total_tokens: i64,
pub cost_usd: f64,
}Expand description
One time-bucket’s aggregated usage.
Fields
ts: Option<String>Bucket start timestamp, RFC3339. None when bucket == None.
messages: i64input_tokens: i64output_tokens: i64cached_tokens: i64total_tokens: i64cost_usd: f64Trait Implementations
Sourceimpl Clone for UsageBucket
impl Clone for UsageBucket
Sourcefn clone(&self) -> UsageBucket
fn clone(&self) -> UsageBucket
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UsageBucket
impl ComposeSchema for UsageBucket
Sourceimpl Debug for UsageBucket
impl Debug for UsageBucket
Sourceimpl<'de> Deserialize<'de> for UsageBucket
impl<'de> Deserialize<'de> for UsageBucket
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UsageBucket
impl JsonSchema for UsageBucket
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for UsageBucket
impl Serialize for UsageBucket