pub struct UsageStatsQuery {
pub user_id: Option<Uuid>,
pub bot_id: Option<Uuid>,
pub channel_id: Option<Uuid>,
pub thread_id: Option<String>,
pub agent_id: Option<String>,
pub since: Option<DateTime<Utc>>,
pub until: Option<DateTime<Utc>>,
pub bucket: Option<Bucket>,
}Expand description
Query parameters accepted by GET /v1/usage/stats.
user_id, bot_id, and channel_id are cloud-only filters; distri-server
accepts (and silently ignores) them to maintain query-param parity.
Fields
user_id: Option<Uuid>Cloud-only: filter by user.
bot_id: Option<Uuid>Cloud-only: filter by bot.
channel_id: Option<Uuid>Cloud-only: filter by channel.
thread_id: Option<String>agent_id: Option<String>since: Option<DateTime<Utc>>until: Option<DateTime<Utc>>bucket: Option<Bucket>Trait Implementations
Sourceimpl Clone for UsageStatsQuery
impl Clone for UsageStatsQuery
Sourcefn clone(&self) -> UsageStatsQuery
fn clone(&self) -> UsageStatsQuery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UsageStatsQuery
impl ComposeSchema for UsageStatsQuery
Sourceimpl Debug for UsageStatsQuery
impl Debug for UsageStatsQuery
Sourceimpl<'de> Deserialize<'de> for UsageStatsQuery
impl<'de> Deserialize<'de> for UsageStatsQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UsageStatsQuery
impl JsonSchema for UsageStatsQuery
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UsageStatsQuery
impl RefUnwindSafe for UsageStatsQuery
impl Send for UsageStatsQuery
impl Sync for UsageStatsQuery
impl Unpin for UsageStatsQuery
impl UnsafeUnpin for UsageStatsQuery
impl UnwindSafe for UsageStatsQuery