pub struct UsageStatsResponse {
pub totals: UsageTotals,
pub buckets: Vec<UsageBucket>,
pub filters_applied: AppliedFilters,
}Expand description
Response body for GET /v1/usage/stats.
Fields
totals: UsageTotalsbuckets: Vec<UsageBucket>filters_applied: AppliedFiltersTrait Implementations
Sourceimpl Clone for UsageStatsResponse
impl Clone for UsageStatsResponse
Sourcefn clone(&self) -> UsageStatsResponse
fn clone(&self) -> UsageStatsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UsageStatsResponse
impl ComposeSchema for UsageStatsResponse
Sourceimpl Debug for UsageStatsResponse
impl Debug for UsageStatsResponse
Sourceimpl<'de> Deserialize<'de> for UsageStatsResponse
impl<'de> Deserialize<'de> for UsageStatsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UsageStatsResponse
impl JsonSchema for UsageStatsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for UsageStatsResponse
impl Serialize for UsageStatsResponse