pub struct UsageTotals {
pub messages: i64,
pub input_tokens: i64,
pub output_tokens: i64,
pub cached_tokens: i64,
pub total_tokens: i64,
pub cost_usd: f64,
}Expand description
Aggregated totals across the full query window.
Fields
messages: i64input_tokens: i64output_tokens: i64cached_tokens: i64total_tokens: i64cost_usd: f64Trait Implementations
Sourceimpl Clone for UsageTotals
impl Clone for UsageTotals
Sourcefn clone(&self) -> UsageTotals
fn clone(&self) -> UsageTotals
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UsageTotals
impl ComposeSchema for UsageTotals
Sourceimpl Debug for UsageTotals
impl Debug for UsageTotals
Sourceimpl Default for UsageTotals
impl Default for UsageTotals
Sourcefn default() -> UsageTotals
fn default() -> UsageTotals
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UsageTotals
impl<'de> Deserialize<'de> for UsageTotals
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UsageTotals
impl JsonSchema for UsageTotals
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for UsageTotals
impl Serialize for UsageTotals