pub struct SecretFieldSpec {
pub key: String,
pub label: Option<String>,
pub description: Option<String>,
pub optional: bool,
}Fields
key: Stringlabel: Option<String>description: Option<String>optional: boolTrait Implementations
Sourceimpl Clone for SecretFieldSpec
impl Clone for SecretFieldSpec
Sourcefn clone(&self) -> SecretFieldSpec
fn clone(&self) -> SecretFieldSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecretFieldSpec
impl Debug for SecretFieldSpec
Sourceimpl<'de> Deserialize<'de> for SecretFieldSpec
impl<'de> Deserialize<'de> for SecretFieldSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SecretFieldSpec
impl JsonSchema for SecretFieldSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SecretFieldSpec
impl PartialEq for SecretFieldSpec
Sourceimpl Serialize for SecretFieldSpec
impl Serialize for SecretFieldSpec
impl Eq for SecretFieldSpec
impl StructuralPartialEq for SecretFieldSpec