pub struct DbConnectionConfig {
pub database_url: String,
pub max_connections: u32,
}Fields
database_url: Stringmax_connections: u32Trait Implementations
Sourceimpl Clone for DbConnectionConfig
impl Clone for DbConnectionConfig
Sourcefn clone(&self) -> DbConnectionConfig
fn clone(&self) -> DbConnectionConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DbConnectionConfig
impl Debug for DbConnectionConfig
Sourceimpl Default for DbConnectionConfig
impl Default for DbConnectionConfig
Sourceimpl<'de> Deserialize<'de> for DbConnectionConfig
impl<'de> Deserialize<'de> for DbConnectionConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DbConnectionConfig
impl JsonSchema for DbConnectionConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DbConnectionConfig
impl RefUnwindSafe for DbConnectionConfig
impl Send for DbConnectionConfig
impl Sync for DbConnectionConfig
impl Unpin for DbConnectionConfig
impl UnwindSafe for DbConnectionConfig