pub struct MemoryStoreConfig {
pub store_type: StoreType,
pub db_config: Option<DbConnectionConfig>,
pub embedding_dimension: usize,
pub similarity_threshold: f32,
pub max_results: usize,
pub openai_api_key: Option<String>,
}Fields
store_type: StoreTypedb_config: Option<DbConnectionConfig>embedding_dimension: usizesimilarity_threshold: f32max_results: usizeopenai_api_key: Option<String>Trait Implementations
Sourceimpl Clone for MemoryStoreConfig
impl Clone for MemoryStoreConfig
Sourcefn clone(&self) -> MemoryStoreConfig
fn clone(&self) -> MemoryStoreConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MemoryStoreConfig
impl Debug for MemoryStoreConfig
Sourceimpl Default for MemoryStoreConfig
impl Default for MemoryStoreConfig
Sourceimpl<'de> Deserialize<'de> for MemoryStoreConfig
impl<'de> Deserialize<'de> for MemoryStoreConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MemoryStoreConfig
impl JsonSchema for MemoryStoreConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MemoryStoreConfig
impl RefUnwindSafe for MemoryStoreConfig
impl Send for MemoryStoreConfig
impl Sync for MemoryStoreConfig
impl Unpin for MemoryStoreConfig
impl UnsafeUnpin for MemoryStoreConfig
impl UnwindSafe for MemoryStoreConfig