pub struct MetadataStoreConfig {
pub store_type: StoreType,
pub db_config: Option<DbConnectionConfig>,
}Fields
store_type: StoreTypedb_config: Option<DbConnectionConfig>Trait Implementations
Sourceimpl Clone for MetadataStoreConfig
impl Clone for MetadataStoreConfig
Sourcefn clone(&self) -> MetadataStoreConfig
fn clone(&self) -> MetadataStoreConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataStoreConfig
impl Debug for MetadataStoreConfig
Sourceimpl Default for MetadataStoreConfig
impl Default for MetadataStoreConfig
Sourceimpl<'de> Deserialize<'de> for MetadataStoreConfig
impl<'de> Deserialize<'de> for MetadataStoreConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MetadataStoreConfig
impl JsonSchema for MetadataStoreConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MetadataStoreConfig
impl RefUnwindSafe for MetadataStoreConfig
impl Send for MetadataStoreConfig
impl Sync for MetadataStoreConfig
impl Unpin for MetadataStoreConfig
impl UnwindSafe for MetadataStoreConfig