pub struct PostgresConfig {
pub database_url: String,
pub max_connections: u32,
pub min_connections: u32,
pub connection_timeout: u64,
pub idle_timeout: u64,
}Fields
database_url: Stringmax_connections: u32min_connections: u32connection_timeout: u64idle_timeout: u64Trait Implementations
Sourceimpl Clone for PostgresConfig
impl Clone for PostgresConfig
Sourcefn clone(&self) -> PostgresConfig
fn clone(&self) -> PostgresConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PostgresConfig
impl Debug for PostgresConfig
Sourceimpl<'de> Deserialize<'de> for PostgresConfig
impl<'de> Deserialize<'de> for PostgresConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PostgresConfig
impl JsonSchema for PostgresConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PostgresConfig
impl RefUnwindSafe for PostgresConfig
impl Send for PostgresConfig
impl Sync for PostgresConfig
impl Unpin for PostgresConfig
impl UnsafeUnpin for PostgresConfig
impl UnwindSafe for PostgresConfig