IntegrationTool

Struct IntegrationTool 

pub struct IntegrationTool { /* private fields */ }
Wrapper for tools that come from integrations This allows us to identify which integration a tool belongs to

Implementations

Source

impl IntegrationTool

pub fn new(tool: Arc<dyn Tool>, integration_name: String) -> Self

Create a new IntegrationTool

pub fn get_integration_name(&self) -> &str

Get the integration name this tool belongs to

pub fn get_tool(&self) -> &Arc<dyn Tool>

Get the underlying tool