pub struct McpServerMetadata {
pub auth_session_key: Option<String>,
pub mcp_transport: TransportType,
pub auth_type: Option<AuthType>,
}Fields
auth_session_key: Option<String>mcp_transport: TransportTypeauth_type: Option<AuthType>Trait Implementations
Sourceimpl Clone for McpServerMetadata
impl Clone for McpServerMetadata
Sourcefn clone(&self) -> McpServerMetadata
fn clone(&self) -> McpServerMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpServerMetadata
impl Debug for McpServerMetadata
Sourceimpl<'de> Deserialize<'de> for McpServerMetadata
impl<'de> Deserialize<'de> for McpServerMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpServerMetadata
impl JsonSchema for McpServerMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpServerMetadata
impl RefUnwindSafe for McpServerMetadata
impl Send for McpServerMetadata
impl Sync for McpServerMetadata
impl Unpin for McpServerMetadata
impl UnsafeUnpin for McpServerMetadata
impl UnwindSafe for McpServerMetadata