pub struct Thread {Show 15 fields
pub id: String,
pub title: String,
pub agent_id: String,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub message_count: u32,
pub last_message: Option<String>,
pub metadata: HashMap<String, Value>,
pub attributes: Value,
pub user_id: Option<String>,
pub external_id: Option<String>,
pub channel_id: Option<String>,
pub input_tokens: u64,
pub output_tokens: u64,
pub total_tokens: u64,
}Fields
id: Stringtitle: Stringagent_id: Stringcreated_at: DateTime<Utc>updated_at: DateTime<Utc>message_count: u32last_message: Option<String>metadata: HashMap<String, Value>attributes: Valueuser_id: Option<String>external_id: Option<String>channel_id: Option<String>Channel ID if this thread originated from a messaging channel
input_tokens: u64Input tokens used across all runs in this thread
output_tokens: u64Output tokens used across all runs in this thread
total_tokens: u64Total tokens used across all runs in this thread
Implementations