pub struct ThreadSummary {Show 14 fields
pub id: String,
pub title: String,
pub agent_id: String,
pub agent_name: String,
pub updated_at: DateTime<Utc>,
pub message_count: u32,
pub last_message: Option<String>,
pub user_id: Option<String>,
pub external_id: Option<String>,
pub channel_id: Option<String>,
pub tags: Option<Vec<String>>,
pub input_tokens: u64,
pub output_tokens: u64,
pub total_tokens: u64,
}Fields
id: Stringtitle: Stringagent_id: Stringagent_name: Stringupdated_at: DateTime<Utc>message_count: u32last_message: Option<String>user_id: Option<String>external_id: Option<String>channel_id: Option<String>Channel ID if this thread originated from a messaging channel
Tags extracted from thread attributes
input_tokens: u64Input tokens used across all runs in this thread
output_tokens: u64Output tokens used across all runs in this thread
total_tokens: u64Total tokens used across all runs in this thread