pub struct UserMessageOverrides {
pub parts: Vec<PartDefinition>,
pub include_artifacts: bool,
pub include_step_count: Option<bool>,
}Fields
parts: Vec<PartDefinition>The parts to include in the user message
include_artifacts: boolIf true, artifacts will be expanded to their actual content (e.g., image artifacts become Part::Image)
include_step_count: Option<bool>If true (default), step count information will be included at the end of the user message