pub struct Message {
pub id: String,
pub name: Option<String>,
pub role: MessageRole,
pub parts: Vec<Part>,
pub created_at: i64,
pub agent_id: Option<String>,
pub parts_metadata: Option<PartsMetadata>,
}Fields
id: Stringname: Option<String>role: MessageRoleparts: Vec<Part>created_at: i64agent_id: Option<String>The ID of the agent that generated this message (for Assistant messages)
parts_metadata: Option<PartsMetadata>Per-part metadata used to control part behavior during save.
Parts with save: false will be filtered out before saving to the database.
This field is used for processing only and is not persisted.
Implementations
Sourceimpl Message
impl Message
pub fn user(task: String, name: Option<String>) -> Self
pub fn system(task: String, name: Option<String>) -> Self
pub fn assistant(task: String, name: Option<String>) -> Self
pub fn developer(task: String, name: Option<String>) -> Self
pub fn tool_response( tool_call_id: String, tool_name: String, result: &Value, ) -> Self
pub fn as_text(&self) -> Option<String>
pub fn tool_calls(&self) -> Vec<ToolCall>
pub fn tool_responses(&self) -> Vec<ToolResponse>
pub fn has_tool_response(&self) -> bool
Sourcepub fn filter_for_save(&self, parts_metadata: Option<&PartsMetadata>) -> Self
pub fn filter_for_save(&self, parts_metadata: Option<&PartsMetadata>) -> Self
Filter parts based on metadata, returning a new Message with only saveable parts.
Parts with save: false in the parts_metadata will be filtered out.
If parts_metadata is None, all parts are included.